@@ -1,22 +1,23 @@
-# parses Tanagra tree description
-# convert to python tree
+# Author:   Bradley Reeves <bradleyaaronreeves@gmail.com>
+# Date:     October 18, 2020
+# About:    Converts a Tanagra tree description from HTML
+#           to a usable format.
 
 import tana2tree.tree as t
 import time
 import re
-import os
 
 class Tanagra_Parser:
     def __init__(self):
         ''' Parameters
             ----------
             self: tanagra parser object
-
             Returns
             -------
             None
         '''
         self.root = None
+        self.orig_labels = {}
 
     def __next_tag(self, s, i):
         ''' Parameters
@@ -24,7 +25,6 @@ class Tanagra_Parser:
             self: tanagra parser object
             s: string to search
             i: starting index as integer
-
             Returns
             -------
             next html tag as string 
@@ -36,7 +36,6 @@ class Tanagra_Parser:
             ----------
             self: tanagra parser object
             file_name: path/name of file as string
-
             Returns
             -------
             file as string 
@@ -44,30 +43,35 @@ class Tanagra_Parser:
         with open(file_name) as file_in:
             return file_in.read()
 
-    def __open_log(self):
-        ''' Parameters
-            ----------
-            self: tanagra parser object
-
-            Returns
-            -------
-            file object for logging 
-        '''
-        os.mkdir("/log")
-        return open("log/tana2tree_log_" + time.strftime("%Y%m%d-%H%M%S") + ".txt", "w+")
-
     def print_tree(self):
         ''' Parameters
             ----------
             self: tanagra parser object
-
             Returns
             -------
             None: prints tree to terminal
         '''
         self.root.print_tree()
     
-    def make_dict(self):
+    def set_orig_labels(self, d, u):
+        ''' Parameters
+            ----------
+            self: tanagra parser object
+            d: tree as dict with unique labels
+            u: dict of labels to update
+
+            Returns
+            -------
+            tree as dict with original labels
+        '''
+        for k, v in d.items():
+            if type(v) is dict:
+                self.set_orig_labels(v, u)
+            elif k == "attr":
+                d[k] = u[v]
+        return d
+    
+    def make_dict(self, unique_values=False):
         ''' Parameters
             ----------
             self: tanagra parser object
@@ -76,14 +80,16 @@ class Tanagra_Parser:
             -------
             tree as dict
         '''
-        return self.root.to_dict(self.root.traverse(self.root))
+        d = self.root.to_dict(self.root.traverse(self.root))
+        if unique_values is False:
+            d = self.set_orig_labels(d, self.orig_labels)
+        return d
 
     def get_node(self, attr):
         ''' Parameters
             ----------
             self: tanagra parser object
             attr: node to retrieve as string
-
             Returns
             -------
             node object as list
@@ -94,7 +100,6 @@ class Tanagra_Parser:
         ''' Parameters
             ----------
             self: tanagra parser object
-
             Returns
             -------
             tree nodes as list
@@ -106,7 +111,6 @@ class Tanagra_Parser:
             ----------
             self: tanagra parser object
             input_file: tanagra description
-
             Returns
             -------
             root node of tree
@@ -135,10 +139,6 @@ class Tanagra_Parser:
         # <\/?[b]> is bold tags
         descr = re.sub("\(.*?\)|<\/?[b]>", "", descr)
 
-        # open file used to log results
-        log = self.__open_log()
-        log.write("Converting Tanagra tree to Python tree object\n")
-
         # loop through all tags in UL
         while not end:
             if self.__next_tag(descr, start_index):
@@ -167,7 +167,11 @@ class Tanagra_Parser:
                         ss = s[:s.find(">")]
                         op = ">="
 
-                    attr = "".join(c[0] for c in ss.split())
+                    attr = ss.split()
+                    # if multiple words, use first character of each word
+                    # otherwise, use the first two characters of word
+                    if len(attr) > 1: attr = "".join(c[0] for c in attr)
+                    else: attr = attr[0][:2]
                     
                     # get the values
                     # [\d]+[.,\d]+ is values w/ commas
@@ -184,40 +188,46 @@ class Tanagra_Parser:
                     post_fix = 0
                     while labels.count(attr) > 1:
                         post_fix = post_fix + 1
-                        attr = attr + "_" + str(post_fix)
+                        if post_fix == 1: attr = attr + "_" + str(post_fix)
+                        else: attr = attr[:-1] + str(post_fix)
                     labels.append(attr)
                     post_fix = 0
 
                     # insert parent nodes
                     if "op" in parents_ops.keys():
                         if parents_ops["op"] == "<":
-                            log.write("inserting " + attr + " into " + parents_ops["parent"] + " as left child...\n")
                             self.root.insert(parents_ops["parent"], parents_ops["op"],  attr, op, value)
                         else:
-                            log.write("inserting " + attr + " into " + parents_ops["parent"] + " as right child...\n")
                             self.root.insert(parents_ops["parent"], parents_ops["op"], attr, op, value)
                     parents_ops = {"parent": attr, "op": op}
+                    self.orig_labels[attr] = ss
 
                     # insert terminal nodes
                     if "then" in s:
                         # extract the target value
-                        target = s[s.find("target = ") + len("target = "):].replace(" ", "")
+                        if s.find("target") != -1:
+                            target = s[s.find("target = ") + len("target = "):].replace(" ", "")
+                        else:
+                            target = s[s.find("class = ") + len("class = "):].replace(" ", "")
+
+                        # store original name
+                        orig_t = target
                         
                         # target values should be unique
                         post_fix = 0
                         while target in labels:
                             post_fix = post_fix + 1
-                            target = target + "_" + str(post_fix)
+                            if post_fix == 1: target = target + "_" + str(post_fix)
+                            else: target = target[:-1] + str(post_fix)
                         labels.append(target)
                         post_fix = 0
                         
                         if op == "<":
-                            log.write("inserting " + target + " into " + attr + " as left child...\n")
                             self.root.insert(attr, op, target, None, None)
                         else:
-                            log.write("inserting " + target + " into " + attr + " as right child...\n")
                             self.root.insert(attr, op, target, None, None) 
-                        parents_ops = {}            
+                        parents_ops = {}
+                        self.orig_labels[target] = orig_t         
                 else:
                     # </UL> encountered, so
                     # go up a tree level
@@ -226,6 +236,4 @@ class Tanagra_Parser:
                 # no more tags found
                 end = True
 
-        log.close()
-        return self.root
-
+        return self.root
\ No newline at end of file
